
******
Events
******

grok provides convenient access to a set of often-used events from Zope 3. Those
events include object and containment events. All events are available as
interface and implemented class.


grok.IContainerModifiedEvent
============================


grok.IObjectAddedEvent
======================


grok.IObjectCopiedEvent
=======================


grok.IObjectCreatedEvent
========================


grok.IObjectModifiedEvent
=========================


grok.IObjectMovedEvent
======================


grok.IObjectRemovedEvent
========================


grok.ContainerModifiedEvent
===========================


grok.ObjectAddedEvent
=====================


grok.ObjectCopiedEvent
======================


grok.ObjectCreatedEvent
=======================


grok.ObjectModifiedEvent
========================


grok.ObjectMovedEvent
=====================


grok.ObjectRemovedEvent
=======================

